<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="lv_LV">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../src/tiled/aboutdialog.ui" line="+14"/>
        <source>About Tiled</source>
        <translation>Par Tiled</translation>
    </message>
    <message utf8="true">
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans&apos;; font-size:8pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt; font-weight:600;&quot;&gt;Tiled (Qt) Map Editor&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-style:italic;&quot;&gt;Version %1&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;Copyright 2008-2009 Thorbjørn Lindeijer&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;(see the AUTHORS file for a full list of contributors)&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;You may modify and redistribute this program under the terms of the GPL (version 2 or later). A copy of the GPL is contained in the &apos;COPYING&apos; file distributed with Tiled (Qt).&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;http://mapeditor.org/&quot;&gt;&lt;span style=&quot; font-size:9pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://mapeditor.org/&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="obsolete">&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans&apos;; font-size:8pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:12pt; font-weight:600;&quot;&gt;Karšu redaktors Tiled (Qt)&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-style:italic;&quot;&gt;Versija %1&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;Autortiesības 2008-2009 Thorbjørn Lindeijer&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;(lai redzētu pilnu sarakstu ar cilvēkiem, kas palīdzējuši izstrādāt šo lietojumprogrammu, skat. datni AUTHORS)&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;Šo programmu atļauts modificēt un izplatīt saskaņā ar GPL licences (versija 2 vai jaunāka) noteikumiem. GPL licences noteikumu kopija tiek izplatīta kopā ar šo lietojumprogrammu un ir atrodama datnē COPYING (angļu valodā).&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;http://mapeditor.org/&quot;&gt;&lt;span style=&quot; font-size:9pt; text-decoration: underline; color:#0000ff;&quot;&gt;http://mapeditor.org/&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location line="+96"/>
        <source>OK</source>
        <translation>Labi</translation>
    </message>
    <message>
        <location filename="../src/tiled/aboutdialog.cpp" line="+32"/>
        <source>&lt;p align=&quot;center&quot;&gt;&lt;font size=&quot;+2&quot;&gt;&lt;b&gt;Tiled Map Editor&lt;/b&gt;&lt;/font&gt;&lt;br&gt;&lt;i&gt;Version %1&lt;/i&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot;&gt;Copyright 2008-2010 Thorbj&amp;oslash;rn Lindeijer&lt;br&gt;(see the AUTHORS file for a full list of contributors)&lt;/p&gt;
&lt;p align=&quot;center&quot;&gt;You may modify and redistribute this program under the terms of the GPL (version 2 or later). A copy of the GPL is contained in the &apos;COPYING&apos; file distributed with Tiled.&lt;/p&gt;
&lt;p align=&quot;center&quot;&gt;&lt;a href=&quot;http://www.mapeditor.org/&quot;&gt;http://www.mapeditor.org/&lt;/a&gt;&lt;/p&gt;
</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>CommandDialog</name>
    <message>
        <location filename="../src/tiled/commanddialog.ui" line="+14"/>
        <source>Properties</source>
        <translation type="unfinished">Rekvizīti</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>&amp;Save map before executing</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Droidcraft::DroidcraftPlugin</name>
    <message>
        <location filename="../src/plugins/droidcraft/droidcraftplugin.cpp" line="+56"/>
        <source>This is not a valid Droidcraft map file!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+44"/>
        <source>The map needs to have exactly one tile layer!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+8"/>
        <source>The layer must have a size of 48 x 48 tiles!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Could not open file for writing.</source>
        <translation type="unfinished">Datni nevareja atvert rakstišanai.</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Droidcraft map files (*.dat)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Lua::LuaPlugin</name>
    <message>
        <location filename="../src/plugins/lua/luaplugin.cpp" line="+46"/>
        <source>Could not open file for writing.</source>
        <translation type="unfinished">Datni nevareja atvert rakstišanai.</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Lua files (*.lua)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/tiled/mainwindow.ui" line="+17"/>
        <source>Tiled</source>
        <translation>Tiled</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;File</source>
        <translation>&amp;Datne</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Recent Files</source>
        <translation>&amp;Nesen izmantotās datnes</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Edit</source>
        <translation>&amp;Rediģēšana</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Help</source>
        <translation>&amp;Palīdzība</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Map</source>
        <translation>&amp;Karte</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;View</source>
        <translation>&amp;Skats</translation>
    </message>
    <message>
        <source>&amp;Layer</source>
        <translation type="obsolete">S&amp;lānis</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Main Toolbar</source>
        <translation>Galvenā rīkjosla</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Open...</source>
        <translation>&amp;Atvērt...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Save</source>
        <translation>&amp;Saglabāt</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Quit</source>
        <translation>&amp;Iziet</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>&amp;Copy</source>
        <translation>&amp;Kopēt</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>&amp;Paste</source>
        <translation>&amp;Ielīmēt</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;About Tiled</source>
        <translation>&amp;Par Tiled</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>About Qt</source>
        <translation>Par Qt</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>&amp;Resize Map...</source>
        <translation>&amp;Mainīt kartes izmēru...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Map &amp;Properties...</source>
        <translation>Kartes &amp;rekvizīti...</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>AutoMap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Show &amp;Grid</source>
        <translation>Rādīt &amp;režģi</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+G</source>
        <translation></translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Save &amp;As...</source>
        <translation>Saglabāt &amp;kā...</translation>
    </message>
    <message>
        <location line="+65"/>
        <source>Save As &amp;Image...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+45"/>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Add External Tileset...</source>
        <translation>&amp;Pievienot ārēju mozaīkattēlu komplektu...</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Snap to Grid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>C&amp;lose All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+Shift+W</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move Layer &amp;Up</source>
        <translation type="obsolete">Pārvietot slāni uz &amp;augšu</translation>
    </message>
    <message>
        <source>Move Layer Dow&amp;n</source>
        <translation type="obsolete">Pārvietot slāni uz &amp;leju</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation type="obsolete">Atlasīt &amp;visu</translation>
    </message>
    <message>
        <source>Select &amp;None</source>
        <translation type="obsolete">&amp;Noņemt atlasi</translation>
    </message>
    <message>
        <location line="-122"/>
        <source>&amp;New...</source>
        <translation>&amp;Izveidot...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>New &amp;Tileset...</source>
        <translation>Izveidot attēļu &amp;komplektu...</translation>
    </message>
    <message>
        <source>&amp;Remove Layer</source>
        <translation type="obsolete">&amp;Dzēst slāni</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>&amp;Close</source>
        <translation>&amp;Aizvērt</translation>
    </message>
    <message>
        <source>Add &amp;Tile Layer...</source>
        <translation type="obsolete">Pievienot &amp;mozaīkslāni...</translation>
    </message>
    <message>
        <source>Add &amp;Object Layer...</source>
        <translation type="obsolete">Pievienot &amp;objektu grupu...</translation>
    </message>
    <message>
        <source>&amp;Duplicate Layer</source>
        <translation type="obsolete">&amp;Izveidot slāņa kopiju</translation>
    </message>
    <message>
        <source>Layer &amp;Properties...</source>
        <translation type="obsolete">Slāņa &amp;rekvizīti...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Zoom In</source>
        <translation>Palielināt skatu</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Zoom Out</source>
        <translation>Samazināt skatu</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Normal Size</source>
        <translation>Iestatīt normālu skatīšanas lielumu</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Ctrl+0</source>
        <translation></translation>
    </message>
    <message>
        <source>Save As Image...</source>
        <translation type="obsolete">Saglabāt kā attēlu...</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Cu&amp;t</source>
        <translation>I&amp;zgriezt</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Offset Map...</source>
        <translation>Iestatīt kartes &amp;nobīdi...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Offsets everything in a layer</source>
        <translation>Veic visu slāņa elementu nobīdi</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Pre&amp;ferences...</source>
        <translation>Ies&amp;tatījumi...</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Clear Recent Files</source>
        <translation>Dzēst datņu vēsturi</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>&amp;Export As...</source>
        <translation>&amp;Eksportēt kā...</translation>
    </message>
</context>
<context>
    <name>MapObjectItem</name>
    <message>
        <source>&amp;Duplicate</source>
        <translation type="obsolete">&amp;Izveidot kopiju</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation type="obsolete">&amp;Dzēst</translation>
    </message>
    <message>
        <source>&amp;Properties...</source>
        <translation type="obsolete">&amp;Rekvizīti...</translation>
    </message>
    <message>
        <source>&amp;Duplicate Object</source>
        <translation type="obsolete">&amp;Izveidot objekta dublikātu</translation>
    </message>
    <message>
        <source>&amp;Remove Object</source>
        <translation type="obsolete">&amp;Noņemt objektu</translation>
    </message>
    <message>
        <source>Object &amp;Properties...</source>
        <translation type="obsolete">Objekta &amp;rekvizīti</translation>
    </message>
</context>
<context>
    <name>MapReader</name>
    <message>
        <location filename="../src/libtiled/mapreader.cpp" line="+130"/>
        <source>Not a map file.</source>
        <translation type="unfinished">Datne nesatur informāciju par karti.</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Not a tileset file.</source>
        <translation type="unfinished">Datne nesatur informaciju par mozaīkelementu komplektu.</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>%3

Line %1, column %2</source>
        <translation type="unfinished">%3

Rinda %1, kolonna %2</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>File not found: %1</source>
        <translation type="unfinished">Datne nav atrasta: %1</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Unable to read file: %1</source>
        <translation type="unfinished">Nav iespejams nolasit datni: %1</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>Unsupported map orientation: &quot;%1&quot;</source>
        <translation type="unfinished">Kartes projekcija nav atbalstita: %1</translation>
    </message>
    <message>
        <location line="+56"/>
        <source>Invalid tileset parameters for tileset &apos;%1&apos;</source>
        <translation type="unfinished">Mozaīkelementu komplektam %1 ir iestatīti nederīgi parametri</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Error while loading tileset &apos;%1&apos;: %2</source>
        <translation type="unfinished">Kļuda mozaīkelementu komplekta %1 ielādes laikā: %2</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Invalid tile ID: %1</source>
        <translation type="unfinished">Nederigs mozaikelementa identifikators: %1</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>Error loading tileset image:
&apos;%1&apos;</source>
        <translation type="unfinished">Kļuda mozaīkelementu komplekta attela ielādes laika:
%1</translation>
    </message>
    <message>
        <location line="+64"/>
        <source>Too many &lt;tile&gt; elements</source>
        <translation type="unfinished">Pārak liels elementu &lt;tile&gt; skaits</translation>
    </message>
    <message>
        <location line="+11"/>
        <location line="+72"/>
        <location line="+39"/>
        <location line="+90"/>
        <source>Invalid tile: %1</source>
        <translation type="unfinished">Nederigs mozaīkelements: %1</translation>
    </message>
    <message>
        <location line="-181"/>
        <source>Unknown encoding: %1</source>
        <translation type="unfinished">Nezināms kodejums: %1</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Compression method &apos;%1&apos; not supported</source>
        <translation type="unfinished">Kompresijas metode %1 nav atbalstīta</translation>
    </message>
    <message>
        <location line="+6"/>
        <location line="+39"/>
        <source>Corrupt layer data for layer &apos;%1&apos;</source>
        <translation type="unfinished">Slāņa %1 dati ir bojāti</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Unable to parse tile at (%1,%2) on layer &apos;%3&apos;</source>
        <translation type="unfinished">Slāņa %3 mozaikelementu ar koordinātam (%1, %2) nav iespejams parsēt</translation>
    </message>
    <message>
        <source>Invalid global tile id (less than 0): %1</source>
        <translation type="obsolete">Nederigs globalais mozaīkelementa identifikators (mazaks nekā 0): %1</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Tile used but no tilesets specified</source>
        <translation type="unfinished">Izmantots mozaīkelements, bet nav norādīts mozaīkelementu komplekts</translation>
    </message>
    <message>
        <location filename="../src/libtiled/mapwriter.cpp" line="+101"/>
        <source>Could not open file for writing.</source>
        <translation type="unfinished">Datni nevareja atvert rakstišanai.</translation>
    </message>
</context>
<context>
    <name>NewImageLayerDialog</name>
    <message>
        <location filename="../src/tiled/newimagelayerdialog.ui" line="+14"/>
        <source>New Tileset</source>
        <translation type="unfinished">Izveidot mozaīkelementu komplektu</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Image layer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Name:</source>
        <translation type="unfinished">&amp;Nosaukums:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Image:</source>
        <translation type="unfinished">Attēls:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Browse...</source>
        <translation type="unfinished">&amp;Pārlūkot...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Use transparent color:</source>
        <translation type="unfinished">Caurredzamā krāsa:</translation>
    </message>
</context>
<context>
    <name>NewMapDialog</name>
    <message>
        <location filename="../src/tiled/newmapdialog.ui" line="+14"/>
        <source>New Map</source>
        <translation>Izveidot karti</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Map size</source>
        <translation>Kartes izmērs</translation>
    </message>
    <message>
        <location line="+6"/>
        <location line="+55"/>
        <source>Width:</source>
        <translation>Platums:</translation>
    </message>
    <message>
        <location line="-32"/>
        <location line="+55"/>
        <source>Height:</source>
        <translation>Augstums:</translation>
    </message>
    <message>
        <location line="-29"/>
        <source>Tile size</source>
        <translation>Mozaīkelementa izmērs</translation>
    </message>
    <message>
        <location line="+78"/>
        <source>Map</source>
        <translation>Karte</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Orientation:</source>
        <translation>Kartes projekcija:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Orthogonal</source>
        <translation>Ortogonāla projekcija</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Isometric</source>
        <translation>Izometriska projekcija</translation>
    </message>
</context>
<context>
    <name>NewTilesetDialog</name>
    <message>
        <location filename="../src/tiled/newtilesetdialog.ui" line="+6"/>
        <source>New Tileset</source>
        <translation>Izveidot mozaīkelementu komplektu</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Tileset</source>
        <translation>Mozaīkelement komplekts</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Name:</source>
        <translation>&amp;Nosaukums:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Image:</source>
        <translation>Attēls:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Browse...</source>
        <translation>&amp;Pārlūkot...</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Use transparent color:</source>
        <translation>Caurredzamā krāsa:</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Tiles</source>
        <translation>Mozaīkelementi</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Tile width:</source>
        <translation>Mozaīkelementa platums:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Margin:</source>
        <translation>Mala ap elementiem:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Tile height:</source>
        <translation>Mozaīkelementa augstums:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Spacing:</source>
        <translation>Atstarpes starp elementiem:</translation>
    </message>
</context>
<context>
    <name>ObjectPropertiesDialog</name>
    <message>
        <location filename="../src/tiled/objectpropertiesdialog.ui" line="+26"/>
        <source>Form</source>
        <translation>Forma</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Name:</source>
        <translation>Nosaukums:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Type:</source>
        <translation>Veids:</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Position</source>
        <translation>Novietojums</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>X:</source>
        <translation></translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Y:</source>
        <translation></translation>
    </message>
    <message>
        <location line="+42"/>
        <source>Size</source>
        <translation>Izmērs</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Width:</source>
        <translation>Platums:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Height:</source>
        <translation>Augstums:</translation>
    </message>
</context>
<context>
    <name>OffsetMapDialog</name>
    <message>
        <location filename="../src/tiled/offsetmapdialog.ui" line="+17"/>
        <source>Offset Map</source>
        <translation>Veikt kartes nobīdi</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Offset Contents of Map</source>
        <translation>Veic kartes elementu nobīdi</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>X:</source>
        <translation></translation>
    </message>
    <message>
        <location line="+23"/>
        <location line="+43"/>
        <source>Wrap</source>
        <translation>Aptīšanās</translation>
    </message>
    <message>
        <location line="-36"/>
        <source>Y:</source>
        <translation></translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Layers:</source>
        <translation>Slāņu izvēle:</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>All Visible Layers</source>
        <translation>Nobīdīt tikai redzamos slāņus</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>All Layers</source>
        <translation>Nobīdīt visus slāņus</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Selected Layer</source>
        <translation>Atlasītais slānis</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Bounds:</source>
        <translation>Robežas:</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Whole Map</source>
        <translation>Izmantot visu karti</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Current Selection</source>
        <translation>Veikt nobīdi pašreizējās atlases robežās</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../src/tiled/preferencesdialog.ui" line="+14"/>
        <source>Preferences</source>
        <translation>Iestatījumi</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Saving and Loading</source>
        <translation>Datņu saglabāšana un ielāde</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Store tile layer data as:</source>
        <translation>&amp;Slāņa datu glabāšanas veids:</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>XML</source>
        <translation></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Base64 (uncompressed)</source>
        <translation>Base64 (bez kompresijas)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Base64 (gzip compressed)</source>
        <translation>Base64 (ar gzip kompresiju)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Base64 (zlib compressed)</source>
        <translation>Base64 (ar zlib kompresiju)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>CSV</source>
        <translation></translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Reload tileset images when they change</source>
        <translation>&amp;Atsvaidzināt mozaīkelementu komplektu attēlus, ja ir veiktas izmaiņas to datnēs</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Not enabled by default since a reference to an external DTD is known to cause problems with some XML parsers.</source>
        <translation>Šī iespēja pēc noklusējuma ir atspējota, jo atsauce uz ārēju DTD var izraisīt problēmas dažos XML parsētājos.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Include &amp;DTD reference in saved maps</source>
        <translation>Iekļaut &amp;DTD atsauci saglabātajās kartēs</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Interface</source>
        <translation>Saskarne</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Language:</source>
        <translation>&amp;Valoda:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Hardware &amp;accelerated drawing (OpenGL)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <location filename="../src/tiled/propertiesdialog.ui" line="+14"/>
        <source>Properties</source>
        <translation>Rekvizīti</translation>
    </message>
</context>
<context>
    <name>ResizeDialog</name>
    <message>
        <location filename="../src/tiled/resizedialog.ui" line="+14"/>
        <source>Resize</source>
        <translation>Mainīt izmēru</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Size</source>
        <translation>Izmēŗs</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Width:</source>
        <translation>Platums:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Height:</source>
        <translation>Augstums:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Offset</source>
        <translation>Nobīde</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>X:</source>
        <translation></translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Y:</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>SaveAsImageDialog</name>
    <message>
        <location filename="../src/tiled/saveasimagedialog.ui" line="+14"/>
        <source>Save As Image</source>
        <translation>Saglabāt kā attēlu</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Location</source>
        <translation>Atrašanās vieta</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Name:</source>
        <translation>Nosaukums:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;Browse...</source>
        <translation>&amp;Pārlūkot...</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Settings</source>
        <translation>Iestatījumi</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Only include &amp;visible layers</source>
        <translation>Iekļaut tikai &amp;redzamos slāņus</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Use current &amp;zoom level</source>
        <translation>Izmantot pašreizējo &amp;skatīšanas lielumu</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Draw tile grid</source>
        <translation>Iekļaut &amp;režģi</translation>
    </message>
</context>
<context>
    <name>Tengine::TenginePlugin</name>
    <message>
        <location filename="../src/plugins/tengine/tengineplugin.cpp" line="+50"/>
        <source>Could not open file for writing.</source>
        <translation type="unfinished">Datni nevareja atvert rakstišanai.</translation>
    </message>
    <message>
        <location line="+243"/>
        <source>T-Engine4 map files (*.lua)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::AbstractObjectTool</name>
    <message numerus="yes">
        <location filename="../src/tiled/abstractobjecttool.cpp" line="+134"/>
        <location line="+54"/>
        <source>Duplicate %n Object(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="-53"/>
        <location line="+71"/>
        <source>Remove %n Object(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="-62"/>
        <location line="+72"/>
        <source>Move %n Object(s) to Layer</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <location line="-62"/>
        <source>Object &amp;Properties...</source>
        <translation type="unfinished">Objekta &amp;rekvizīti</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::AutoMapper</name>
    <message>
        <location filename="../src/tiled/automap.cpp" line="+116"/>
        <source>Multiple layers %1 found!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+110"/>
        <source>No ruleRegions layer found!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>No set layers found!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>No ruleSet layer found!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+212"/>
        <source>Tile</source>
        <translation type="unfinished">Mozaīkelements</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::AutomaticMappingManager</name>
    <message>
        <location line="+497"/>
        <source>No set layer found!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Apply AutoMap rules</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+18"/>
        <source>No rules file found at:
%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Error opening rules file:
%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+19"/>
        <source>File not found:
%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Opening rules map failed:
%1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::BucketFillTool</name>
    <message>
        <location filename="../src/tiled/bucketfilltool.cpp" line="+39"/>
        <location line="+133"/>
        <source>Bucket Fill Tool</source>
        <translation>Aizpildīšanas rīks</translation>
    </message>
    <message>
        <location line="-130"/>
        <location line="+131"/>
        <source>F</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::CommandButton</name>
    <message>
        <location filename="../src/tiled/commandbutton.cpp" line="+39"/>
        <source>Execute Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>F5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Error Executing Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>You do not have any commands setup.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Edit commands...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+45"/>
        <source>Edit Commands...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::CommandDataModel</name>
    <message>
        <location filename="../src/tiled/commanddatamodel.cpp" line="+60"/>
        <source>Open in text editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+92"/>
        <location line="+67"/>
        <source>&lt;new command&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-59"/>
        <source>Set a name for this command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Set the shell command to execute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Show or hide this command in the command list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Add a new command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+101"/>
        <source>Name</source>
        <translation type="unfinished">Nosaukums</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Enable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Move Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Move Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Execute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Execute in Terminal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+84"/>
        <source>%1 (copy)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+16"/>
        <source>New command</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::CommandDialog</name>
    <message>
        <location filename="../src/tiled/commanddialog.cpp" line="+40"/>
        <source>Edit Commands</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::CommandProcess</name>
    <message>
        <location filename="../src/tiled/command.cpp" line="+122"/>
        <source>Unable to create/open %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Unable to add executable permissions to %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+26"/>
        <source>The command failed to start.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>The command crashed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>The command timed out.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>An unknown error occurred.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Error Executing %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::CreateObjectTool</name>
    <message>
        <location filename="../src/tiled/createobjecttool.cpp" line="+42"/>
        <location line="+100"/>
        <source>O</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Insert Objects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Insert Tile Objects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>T</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::Eraser</name>
    <message>
        <location filename="../src/tiled/eraser.cpp" line="+34"/>
        <location line="+36"/>
        <source>Eraser</source>
        <translation>Dzēšgumija</translation>
    </message>
    <message>
        <location line="-33"/>
        <location line="+34"/>
        <source>E</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::ImageLayerPropertiesDialog</name>
    <message>
        <location filename="../src/tiled/imagelayerpropertiesdialog.cpp" line="+60"/>
        <source>Image Layer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Browse...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Image:</source>
        <translation type="unfinished">Attēls:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Transparent color:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Layer Image</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::LayerDock</name>
    <message>
        <location filename="../src/tiled/layerdock.cpp" line="+179"/>
        <source>Layers</source>
        <translation>Slāņi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Opacity:</source>
        <translation>Necaurredzamība:</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::LayerModel</name>
    <message>
        <location filename="../src/tiled/layermodel.cpp" line="+122"/>
        <source>Layer</source>
        <translation>Slānis</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::LayerView</name>
    <message>
        <source>Properties...</source>
        <translation type="obsolete">Rekvizīti...</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::MainWindow</name>
    <message>
        <location filename="../src/tiled/mainwindow.cpp" line="+134"/>
        <location line="+8"/>
        <source>Undo</source>
        <translation>Atsaukt darbību</translation>
    </message>
    <message>
        <location line="-7"/>
        <location line="+6"/>
        <source>Redo</source>
        <translation>Atatsaukt darbību</translation>
    </message>
    <message>
        <source>Error while opening map</source>
        <translation type="obsolete">Kartes atvēršanas laikā radās kļūda</translation>
    </message>
    <message>
        <location line="+418"/>
        <source>Open Map</source>
        <translation>Atvērt karti</translation>
    </message>
    <message>
        <location line="-13"/>
        <location line="+76"/>
        <source>Tiled map files (*.tmx)</source>
        <translation>Lietojumprogrammas Tiled karšu formāts (*.tmx)</translation>
    </message>
    <message>
        <source>Error while saving map</source>
        <translation type="obsolete">Kartes saglabāšanas laikā radās kļūda</translation>
    </message>
    <message>
        <location line="-451"/>
        <source>Ctrl+=</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>+</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>-</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+22"/>
        <location line="+1047"/>
        <source>&amp;Layer</source>
        <translation>S&amp;lānis</translation>
    </message>
    <message>
        <location line="-910"/>
        <source>Ctrl+PgUp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Ctrl+PgDown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>X</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Y</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+127"/>
        <source>Error Opening Map</source>
        <translation>Kartes atvēršanas laikā radās kļūda</translation>
    </message>
    <message>
        <location line="+73"/>
        <location line="+135"/>
        <source>All Files (*)</source>
        <translation>Visas datnes (*)</translation>
    </message>
    <message>
        <location line="-94"/>
        <location line="+141"/>
        <source>Error Saving Map</source>
        <translation>Kartes saglabāšanas laikā radās kļūda</translation>
    </message>
    <message>
        <location line="-108"/>
        <source>untitled.tmx</source>
        <translation>nenosaukts.tmx</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Unsaved Changes</source>
        <translation>Nesaglabātās izmaiņas</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>There are unsaved changes. Do you want to save now?</source>
        <translation>Ir veiktas nesaglabātas izmaiņas. Vai vēlaties tās saglabāt?</translation>
    </message>
    <message>
        <location line="+52"/>
        <source>Export As...</source>
        <translation>Eksportēt kā...</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>Unknown File Format</source>
        <translation>Datnes formāts nav atpazīts</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The given filename does not have any known file extension.</source>
        <translation>Dotās datnes paplašinājums nav zināms.</translation>
    </message>
    <message>
        <location line="+41"/>
        <source>Cut</source>
        <translation>Izgriezt</translation>
    </message>
    <message>
        <location line="+80"/>
        <source>Paste Objects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+370"/>
        <source>[*]%1 - Tiled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Tilesets</source>
        <translation type="obsolete">Pievienot mozaīkelementu komplektus</translation>
    </message>
    <message>
        <location line="-291"/>
        <source>Add External Tileset</source>
        <translation>Pievienot ārēju mozaīkattēlu komplektu</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Tiled tileset files (*.tsx)</source>
        <translation>Lietojumprogrammas Tiled mozaīkattēlu komplektu datnes (*.tsx)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Error Reading Tileset</source>
        <translation>Mozaīkattēlu komplekta nolasīšanas laikā radās kļūda</translation>
    </message>
    <message>
        <location line="+46"/>
        <source>Map</source>
        <translation>Karte</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Automatic Mapping</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+120"/>
        <source>%1%</source>
        <translation></translation>
    </message>
    <message>
        <source>Add Tile Layer</source>
        <translation type="obsolete">Pievienot slāni</translation>
    </message>
    <message>
        <source>Add Object Layer</source>
        <translation type="obsolete">Pievienot objektu grupu</translation>
    </message>
    <message>
        <source>Layer name:</source>
        <translation type="obsolete">Slāņa nosaukums:</translation>
    </message>
    <message>
        <source>New Layer</source>
        <translation type="obsolete">Nenosaukts slānis</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::MapDocument</name>
    <message>
        <location filename="../src/tiled/mapdocument.cpp" line="+133"/>
        <source>untitled.tmx</source>
        <translation type="unfinished">nenosaukts.tmx</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>Resize Map</source>
        <translation>Mainīt kartes izmēru</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Offset Map</source>
        <translation>Veikt kartes nobīdi</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Tile Layer %1</source>
        <translation>Mozaīkelementu slānis %1</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Object Layer %1</source>
        <translation>Objektu grupa %1</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Copy of %1</source>
        <translation>%1 (kopija)</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Duplicate Layer</source>
        <translation>Veikt slāņa kopiju</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Merge Layer Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+138"/>
        <source>Tile</source>
        <translation type="unfinished">Mozaīkelements</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Tileset Changes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::MapDocumentActionHandler</name>
    <message>
        <location filename="../src/tiled/mapdocumentactionhandler.cpp" line="+126"/>
        <source>Select &amp;All</source>
        <translation>Atlasīt &amp;visu</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Select &amp;None</source>
        <translation>&amp;Noņemt atlasi</translation>
    </message>
    <message>
        <location line="-81"/>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <source>Add &amp;Tile Layer...</source>
        <translation type="obsolete">Pievienot &amp;mozaīkslāni...</translation>
    </message>
    <message>
        <source>Add &amp;Object Layer...</source>
        <translation type="obsolete">Pievienot &amp;objektu grupu...</translation>
    </message>
    <message>
        <location line="+87"/>
        <source>&amp;Duplicate Layer</source>
        <translation>&amp;Izveidot slāņa kopiju</translation>
    </message>
    <message>
        <location line="-79"/>
        <source>Ctrl+Shift+D</source>
        <translation>Ctrl+Shift+D</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>PgUp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>PgDown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Ctrl+Shift+H</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+48"/>
        <source>&amp;Crop to Selection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Add &amp;Tile Layer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Add &amp;Object Layer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>&amp;Merge Layer Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&amp;Remove Layer</source>
        <translation>&amp;Dzēst slāni</translation>
    </message>
    <message>
        <source>Move Layer &amp;Up</source>
        <translation type="obsolete">Pārvietot slāni uz &amp;augšu</translation>
    </message>
    <message>
        <location line="-64"/>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+Uz augšu</translation>
    </message>
    <message>
        <source>Move Layer Dow&amp;n</source>
        <translation type="obsolete">Pārvietot slāni uz &amp;leju</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+Uz leju</translation>
    </message>
    <message>
        <location line="+60"/>
        <source>Select Pre&amp;vious Layer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Select &amp;Next Layer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>R&amp;aise Layer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&amp;Lower Layer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Show/&amp;Hide all Other Layers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Layer &amp;Properties...</source>
        <translation>Slāņa &amp;rekvizīti...</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::NewMapDialog</name>
    <message>
        <source>Layer 1</source>
        <translation type="obsolete">Slānis 1</translation>
    </message>
    <message>
        <location filename="../src/tiled/newmapdialog.cpp" line="+81"/>
        <source>Tile Layer 1</source>
        <translation>1. mozaīkelementu slānis</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::NewTilesetDialog</name>
    <message>
        <location filename="../src/tiled/newtilesetdialog.cpp" line="+123"/>
        <location line="+7"/>
        <source>Error</source>
        <translation>Kļūda</translation>
    </message>
    <message>
        <location line="-6"/>
        <source>Failed to load tileset image &apos;%1&apos;.</source>
        <translation>Neizdevās ielādēt mozaīkattēlu komplekta attēlu %1.</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>No tiles found in the tileset image when using the given tile size, margin and spacing!</source>
        <translation>Dotā attēla un mozaīkelementu izmēra, malu un atstarpju informācijas kombinācija nav derīga.</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Tileset Image</source>
        <translation>Mozaīkelementu komplekta attēls</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::ObjectGroupPropertiesDialog</name>
    <message>
        <location filename="../src/tiled/objectgrouppropertiesdialog.cpp" line="+43"/>
        <source>Object Layer</source>
        <translation>Objektu grupa</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Color:</source>
        <translation>Krāsa:</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::ObjectPropertiesDialog</name>
    <message>
        <location filename="../src/tiled/objectpropertiesdialog.cpp" line="+41"/>
        <source>Object</source>
        <translation>Objekts</translation>
    </message>
    <message>
        <location line="+52"/>
        <source>Change Object</source>
        <translation>Mainīt objektu</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::ObjectSelectionTool</name>
    <message>
        <location filename="../src/tiled/objectselectiontool.cpp" line="+98"/>
        <location line="+110"/>
        <source>Select Objects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-108"/>
        <location line="+109"/>
        <source>S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Object &amp;Properties...</source>
        <translation type="obsolete">Objekta &amp;rekvizīti</translation>
    </message>
    <message numerus="yes">
        <location line="+117"/>
        <source>Move %n Object(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::PreferencesDialog</name>
    <message>
        <location filename="../src/tiled/preferencesdialog.cpp" line="+56"/>
        <location line="+23"/>
        <source>System default</source>
        <translation>Sistēmas valoda</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::PropertiesDialog</name>
    <message>
        <location filename="../src/tiled/propertiesdialog.cpp" line="+69"/>
        <source>%1 Properties</source>
        <translation>Objekta %1 rekvizīti</translation>
    </message>
    <message>
        <location line="+37"/>
        <source>Layer</source>
        <translation>Slānis</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::PropertiesModel</name>
    <message>
        <location filename="../src/tiled/propertiesmodel.cpp" line="+51"/>
        <source>&lt;new property&gt;</source>
        <translation>&lt;jauns rekvizīts&gt;</translation>
    </message>
    <message>
        <location line="+68"/>
        <source>Name</source>
        <translation>Nosaukums</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Value</source>
        <translation>Vērtība</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::SaveAsImageDialog</name>
    <message>
        <location filename="../src/tiled/saveasimagedialog.cpp" line="+111"/>
        <source>Save as Image</source>
        <translation>Saglabāt kā attēlu</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>Datne %1 jau pastāv. Vai vēlaties to pārrakstīt?</translation>
    </message>
    <message>
        <location line="+73"/>
        <source>Image</source>
        <translation>Attēls</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::SelectionTool</name>
    <message>
        <location filename="../src/tiled/selectiontool.cpp" line="+34"/>
        <location line="+81"/>
        <source>Rectangular Select</source>
        <translation>Četrstūrveida atlase</translation>
    </message>
    <message>
        <location line="-78"/>
        <location line="+79"/>
        <source>R</source>
        <translation></translation>
    </message>
    <message>
        <location line="-56"/>
        <source>%1, %2 - Rectangle: (%3 x %4)</source>
        <translation>%1, %2 - Četrstūris: (%3 x %4)</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::StampBrush</name>
    <message>
        <location filename="../src/tiled/stampbrush.cpp" line="+38"/>
        <location line="+281"/>
        <source>Stamp Brush</source>
        <translation>Spiedogs</translation>
    </message>
    <message>
        <location line="-278"/>
        <location line="+279"/>
        <source>B</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::TilesetDock</name>
    <message>
        <location filename="../src/tiled/tilesetdock.cpp" line="+279"/>
        <source>Remove Tileset</source>
        <translation>Dzēst mozaīkelementu komplektu</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The tileset &quot;%1&quot; is still in use by the map!</source>
        <translation>Kartē joprojām izmantoti mozaīkelementi no komplekta %1.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Remove this tileset and all references to the tiles in this tileset?</source>
        <translation>Vai dzēst šo mozaīkelementu komplektu un visas atsauces uz to?</translation>
    </message>
    <message>
        <location line="+64"/>
        <source>Tilesets</source>
        <translation>Mozaīkelementu komplekti</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::TilesetView</name>
    <message>
        <source>Properties...</source>
        <translation type="obsolete">Rekvizīti...</translation>
    </message>
    <message>
        <location filename="../src/tiled/tilesetview.cpp" line="+213"/>
        <source>Tile &amp;Properties...</source>
        <translation>Mozaīkelementa &amp;rekvizīti ...</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>&amp;Export Tileset As...</source>
        <translation>&amp;Eksportēt mozaīkelementu komplektu kā ...</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&amp;Import Tileset</source>
        <translation>&amp;Importēt mozaīkelementu komplektu</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Show &amp;Grid</source>
        <translation type="unfinished">Rādīt &amp;režģi</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Tile</source>
        <translation>Mozaīkelements</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Export Tileset</source>
        <translation>Eksportēt mozaīkelementu komplektu</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Tiled tileset files (*.tsx)</source>
        <translation>Lietojumprogrammas Tiled mozaīkattēlu komplektu datnes (*.tsx)</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::ToolManager</name>
    <message>
        <location filename="../src/tiled/toolmanager.cpp" line="+88"/>
        <source>Tools</source>
        <translation>Rīki</translation>
    </message>
</context>
<context>
    <name>Tiled::Internal::UndoDock</name>
    <message>
        <location filename="../src/tiled/undodock.cpp" line="+64"/>
        <source>History</source>
        <translation>Vēsture</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>&lt;empty&gt;</source>
        <translation>&lt;nav vēstures&gt;</translation>
    </message>
</context>
<context>
    <name>Tmw::TmwPlugin</name>
    <message>
        <location filename="../src/plugins/tmw/tmwplugin.cpp" line="+47"/>
        <source>Multiple collision layers found!</source>
        <translation>Pastāv vairaki sadursmjus slāni.</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>No collision layer found!</source>
        <translation>Nav atrasts neviens sadursmju slānis.</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Could not open file for writing.</source>
        <translation>Datni nevareja atvert rakstišanai.</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>TMW-eAthena collision files (*.wlk)</source>
        <translation>TMW-eAthena sadursmju datnes (*.wlk)</translation>
    </message>
</context>
<context>
    <name>TmxMapReader</name>
    <message>
        <location filename="../src/tiled/tmxmapreader.h" line="+55"/>
        <location filename="../src/tiled/tmxmapwriter.h" line="+56"/>
        <source>Tiled map files (*.tmx)</source>
        <translation>Lietojumprogrammas Tiled karšu formāts (*.tmx)</translation>
    </message>
    <message>
        <source>Could not open file for writing.</source>
        <translation type="obsolete">Datni nevareja atvert rakstišanai.</translation>
    </message>
</context>
<context>
    <name>TmxReader</name>
    <message>
        <source>Not a map file.</source>
        <translation type="obsolete">Datne nesatur informāciju par karti.</translation>
    </message>
    <message>
        <source>Not a tileset file.</source>
        <translation type="obsolete">Datne nesatur informaciju par mozaīkelementu komplektu.</translation>
    </message>
    <message>
        <source>%3

Line %1, column %2</source>
        <translation type="obsolete">%3

Rinda %1, kolonna %2</translation>
    </message>
    <message>
        <source>File not found: %1</source>
        <translation type="obsolete">Datne nav atrasta: %1</translation>
    </message>
    <message>
        <source>Unable to read file: %1</source>
        <translation type="obsolete">Nav iespejams nolasit datni: %1</translation>
    </message>
    <message>
        <source>Unsupported map orientation: &quot;%1&quot;</source>
        <translation type="obsolete">Kartes projekcija nav atbalstita: %1</translation>
    </message>
    <message>
        <source>Invalid tileset parameters for tileset &apos;%1&apos;</source>
        <translation type="obsolete">Mozaīkelementu komplektam %1 ir iestatīti nederīgi parametri</translation>
    </message>
    <message>
        <source>Error while loading tileset &apos;%1&apos;: %2</source>
        <translation type="obsolete">Kļuda mozaīkelementu komplekta %1 ielādes laikā: %2</translation>
    </message>
    <message>
        <source>Invalid tile ID: %1</source>
        <translation type="obsolete">Nederigs mozaikelementa identifikators: %1</translation>
    </message>
    <message>
        <source>Error loading tileset image:
&apos;%1&apos;</source>
        <translation type="obsolete">Kļuda mozaīkelementu komplekta attela ielādes laika:
%1</translation>
    </message>
    <message>
        <source>Too many &lt;tile&gt; elements</source>
        <translation type="obsolete">Pārak liels elementu &lt;tile&gt; skaits</translation>
    </message>
    <message>
        <source>Invalid tile: %1</source>
        <translation type="obsolete">Nederigs mozaīkelements: %1</translation>
    </message>
    <message>
        <source>Unknown encoding: %1</source>
        <translation type="obsolete">Nezināms kodejums: %1</translation>
    </message>
    <message>
        <source>Compression method &apos;%1&apos; not supported</source>
        <translation type="obsolete">Kompresijas metode %1 nav atbalstīta</translation>
    </message>
    <message>
        <source>Corrupt layer data for layer &apos;%1&apos;</source>
        <translation type="obsolete">Slāņa %1 dati ir bojāti</translation>
    </message>
    <message>
        <source>Unable to parse tile at (%1,%2) on layer &apos;%3&apos;</source>
        <translation type="obsolete">Slāņa %3 mozaikelementu ar koordinātam (%1, %2) nav iespejams parsēt</translation>
    </message>
    <message>
        <source>Invalid global tile id (less than 0): %1</source>
        <translation type="obsolete">Nederigs globalais mozaīkelementa identifikators (mazaks nekā 0): %1</translation>
    </message>
    <message>
        <source>Tile used but no tilesets specified</source>
        <translation type="obsolete">Izmantots mozaīkelements, bet nav norādīts mozaīkelementu komplekts</translation>
    </message>
</context>
<context>
    <name>TmxViewer</name>
    <message>
        <location filename="../src/tmxviewer/tmxviewer.cpp" line="+160"/>
        <source>TMX Viewer</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Undo Commands</name>
    <message>
        <location filename="../src/tiled/addremovelayer.h" line="+67"/>
        <source>Add Layer</source>
        <translation>Pievienot slani</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Remove Layer</source>
        <translation>Dzēst slāni</translation>
    </message>
    <message>
        <location filename="../src/tiled/addremovemapobject.cpp" line="+79"/>
        <source>Add Object</source>
        <translation>Pievienot objektu</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Remove Object</source>
        <translation>Dzēst objektu</translation>
    </message>
    <message>
        <location filename="../src/tiled/addremovetileset.cpp" line="+62"/>
        <source>Add Tileset</source>
        <translation>Pievienot mozaīkelementu komplektu</translation>
    </message>
    <message>
        <location filename="../src/tiled/addremovetileset.h" line="+78"/>
        <source>Remove Tileset</source>
        <translation>Dzēst mozaīkelementu komplektu</translation>
    </message>
    <message>
        <location filename="../src/tiled/changemapobject.cpp" line="+35"/>
        <source>Change Object</source>
        <translation>Mainīt objektu</translation>
    </message>
    <message>
        <location filename="../src/tiled/changeobjectgroupproperties.cpp" line="+37"/>
        <location filename="../src/tiled/objectgrouppropertiesdialog.cpp" line="+21"/>
        <source>Change Object Layer Properties</source>
        <translation>Mainīt objektu grupas rekvizītus</translation>
    </message>
    <message>
        <location filename="../src/tiled/changeproperties.cpp" line="+34"/>
        <source>Change %1 Properties</source>
        <translation>Mainīt objekta %1 rekvizītus</translation>
    </message>
    <message>
        <location filename="../src/tiled/changetileselection.cpp" line="+31"/>
        <source>Change Selection</source>
        <translation>Mainīt atlasi</translation>
    </message>
    <message>
        <location filename="../src/tiled/erasetiles.cpp" line="+39"/>
        <source>Erase</source>
        <translation>Dzest</translation>
    </message>
    <message>
        <location filename="../src/tiled/filltiles.cpp" line="+36"/>
        <source>Fill Area</source>
        <translation>Aizpildīt apgabalu</translation>
    </message>
    <message>
        <source>Move Layer Down</source>
        <translation type="obsolete">Pārvietot slāni uz leju</translation>
    </message>
    <message>
        <source>Move Layer Up</source>
        <translation type="obsolete">Pārvietot slāni uz augšu</translation>
    </message>
    <message>
        <location filename="../src/tiled/movemapobject.cpp" line="+39"/>
        <source>Move Object</source>
        <translation>Pārvietot objektu</translation>
    </message>
    <message>
        <location filename="../src/tiled/offsetlayer.cpp" line="+40"/>
        <source>Offset Layer</source>
        <translation>Veikt slāņa nobidi</translation>
    </message>
    <message>
        <location filename="../src/tiled/painttilelayer.cpp" line="+49"/>
        <source>Paint</source>
        <translation>Zīmēt</translation>
    </message>
    <message>
        <location filename="../src/tiled/renamelayer.cpp" line="+40"/>
        <source>Rename Layer</source>
        <translation>Mainīt slāņa nosaukumu</translation>
    </message>
    <message>
        <location filename="../src/tiled/resizelayer.cpp" line="+37"/>
        <source>Resize Layer</source>
        <translation>Mainīt slāņa izmēru</translation>
    </message>
    <message>
        <location filename="../src/tiled/resizemap.cpp" line="+32"/>
        <source>Resize Map</source>
        <translation>Mainīt kartes izmēru</translation>
    </message>
    <message>
        <location filename="../src/tiled/resizemapobject.cpp" line="+39"/>
        <source>Resize Object</source>
        <translation>Mainīt objekta izmēru</translation>
    </message>
    <message>
        <location filename="../src/tiled/movetileset.cpp" line="+31"/>
        <source>Move Tileset</source>
        <translation>Pārvietot mozaīkelementu komplektu</translation>
    </message>
    <message>
        <location filename="../src/tiled/tilesetview.cpp" line="-159"/>
        <source>Import Tileset</source>
        <translation>Importēt mozaīkelementu komplektu</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Export Tileset</source>
        <translation>Eksportēt mozaīkelementu komplektu</translation>
    </message>
    <message>
        <location filename="../src/tiled/movemapobjecttogroup.cpp" line="+40"/>
        <source>Move Object to Layer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/tiled/changeimagelayerproperties.cpp" line="+39"/>
        <location filename="../src/tiled/imagelayerpropertiesdialog.cpp" line="+28"/>
        <source>Change Image Layer Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/tiled/movelayer.cpp" line="+37"/>
        <source>Lower Layer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Raise Layer</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <location filename="../src/tiled/utils.cpp" line="+31"/>
        <source>Image files</source>
        <translation>Attelu datnes</translation>
    </message>
</context>
</TS>
